==> 4.1.0.tar.gz: lib/src/data/repositories/user_repository_impl.dart <==
import 'dart:async';

import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/exceptions.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/user_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/legal_document_model.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/user_accept_enrollment_form_response.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/user_get_enrollment_form_response.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/user_login_response.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/entities/legal_document.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/user_repository.dart';

class UserRepositoryImpl implements UserRepository {
  final UserRemoteDataSource? remoteDataSource;

  UserRepositoryImpl({
    required this.remoteDataSource,
  });

  @override
  Future<Either<Failure, UserLoginResponse>> login({
    required String externalId,
    required String? email,
    String? referralCode,
  }) async {
    try {
      final failureOrUserLoginResponse = await remoteDataSource!.login(
        externalId: externalId,
        email: email,
        referralCode: referralCode,
      );

      if (failureOrUserLoginResponse.isRight()) {
        final userLoginResponse =
            failureOrUserLoginResponse.getOrElse(() => UserLoginResponse());
        if (userLoginResponse.legalTermsAccepted) {
          final jwt = userLoginResponse.sessionToken;
          final clientType = userLoginResponse.clientType;

          ConfigReader.setUserJwt(jwt);
          ConfigReader.setClientType(clientType);
        }
      }

      return failureOrUserLoginResponse;
    } on ServerException {
      return Left(ServerFailure());
    }
  }

  @override
  Future<Either<Failure, void>> logOut() async {
    try {
      ConfigReader.setUserJwt(null);
      return Right(null);
    } on CacheException {
      return Left(CacheFailure());
    }
  }

  @override
  Future<Either<Failure, UserGetEnrollmentFormResponse>> getEnrollmentForm({
    required String? jwt,
  }) async {
    return await remoteDataSource!.getEnrollmentForm(
      jwt: jwt,
    );
  }

  @override
  Future<Either<Failure, UserAcceptEnrollmentFormResponse>>
      acceptEnrollmentForm({
    required String? jwt,
    required List<LegalDocument>? legalDocumentsAccepted,
  }) async {
    try {
      final failureOrAcceptEnrollmentResponse =
          await remoteDataSource!.acceptEnrollmentForm(
        jwt: jwt,
        legalDocumentsAccepted:
            legalDocumentsAccepted as List<LegalDocumentModel>,
      );

      if (failureOrAcceptEnrollmentResponse.isRight()) {
        final acceptEnrollmentResponse = failureOrAcceptEnrollmentResponse
            .getOrElse(() => UserAcceptEnrollmentFormResponse());
        final jwt = acceptEnrollmentResponse.sessionToken;
        final clientType = acceptEnrollmentResponse.clientType;

        ConfigReader.setUserJwt(jwt);
        ConfigReader.setClientType(clientType);
      }
      return failureOrAcceptEnrollmentResponse;
    } on ServerException {
      return Left(ServerFailure());
    }
  }

  @override
  Future<Either<Failure, dynamic>> getUserData() async {
    return await remoteDataSource!.getUserData();
  }

  @override
  Future<Either<Failure, dynamic>> updateUserData({
    String? alias,
    String? gender,
    String? birthdate,
  }) async {
    return await remoteDataSource!.updateUserData(
      alias: alias,
      gender: gender,
      birthdate: birthdate,
    );
  }
}

==> 4.4.2.tar.gz: lib/src/data/repositories/user_repository_impl.dart <==
import 'dart:async';

import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/exceptions.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/user_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/user_accept_enrollment_form_response.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/user_login_response.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/user_repository.dart';

class UserRepositoryImpl implements UserRepository {
  final UserRemoteDataSource? remoteDataSource;

  UserRepositoryImpl({
    required this.remoteDataSource,
  });

  @override
  Future<Either<Failure, UserLoginResponse>> login({
    required String externalId,
    required String? email,
    String? referralCode,
  }) async {
    try {
      final failureOrUserLoginResponse = await remoteDataSource!.login(
        externalId: externalId,
        email: email,
        referralCode: referralCode,
      );

      return failureOrUserLoginResponse;
    } on ServerException {
      return Left(ServerFailure());
    }
  }

  @override
  Future<Either<Failure, void>> logOut() async {
    try {
      ConfigReader.setUserJwt(null);
      return Right(null);
    } on CacheException {
      return Left(CacheFailure());
    }
  }

  @override
  Future<Either<Failure, UserAcceptEnrollmentFormResponse>>
      acceptEnrollmentForm({
    required String? jwt,
    required List<String>? legalDocumentsAccepted,
  }) async {
    try {
      final failureOrAcceptEnrollmentResponse =
          await remoteDataSource!.acceptEnrollmentForm(
        jwt: jwt,
        legalDocumentsAccepted: legalDocumentsAccepted,
      );

      return failureOrAcceptEnrollmentResponse;
    } on ServerException {
      return Left(ServerFailure());
    }
  }

  @override
  Future<Either<Failure, dynamic>> getUserData() async {
    return await remoteDataSource!.getUserData();
  }

  @override
  Future<Either<Failure, dynamic>> updateUserData({
    String? alias,
    String? gender,
    String? birthdate,
  }) async {
    return await remoteDataSource!.updateUserData(
      alias: alias,
      gender: gender,
      birthdate: birthdate,
    );
  }
}
